@@ -322,14 +322,13 @@ class ServiceRunTestCase(unittest.TestCase):
         container_ports = ['80:80/tcp', '22:22']
         container_envvars = ['MYSQL_ADMIN=admin', 'MYSQL_PASS=password']
         linked_to_service = ['mysql:mysql', 'redis:redis']
-        linked_to_container = ['mariadb:mariadb', 'wordpress:wordpress']
 
         service = tutumcli.commands.tutum.Service()
         service.uuid = '7A4CFE51-03BB-42D6-825E-3B533888D8CD'
         mock_create.return_value = service
         mock_start.return_value = True
         service_run('imagename', 'containername', 1, '256M', '1024M', 3, '-d', '/bin/mysql',
-                    container_ports, container_envvars, linked_to_service, linked_to_container,
+                    container_ports, container_envvars, linked_to_service,
                     'OFF', 'OFF', 'OFF', 'poweruser', True)
 
         mock_create.assert_called_with(image='imagename', name='containername', cpu_shares=1,
@@ -338,7 +337,6 @@ class ServiceRunTestCase(unittest.TestCase):
                                        entrypoint='/bin/mysql', container_ports=utils.parse_ports(container_ports),
                                        container_envvars=utils.parse_envvars(container_envvars),
                                        linked_to_service=utils.parse_links(linked_to_service, 'to_service'),
-                                       linked_to_container=utils.parse_links(linked_to_container, 'to_container'),
                                        autorestart='OFF', autoreplace='OFF', autodestroy='OFF',
                                        roles='poweruser', sequential_deployment=True)
         mock_save.asser_called()
@@ -351,9 +349,8 @@ class ServiceRunTestCase(unittest.TestCase):
         container_ports = ['80:80/tcp', '22:22']
         container_envvars = ['MYSQL_ADMIN=admin', 'MYSQL_PASS=password']
         linked_to_service = ['mysql:mysql', 'redis:redis']
-        linked_to_container = ['mariadb:mariadb', 'wordpress:wordpress']
         service_run('imagename', 'containername', 1, '256M', '1024M', 3, '-d', '/bin/mysql',
-                    container_ports, container_envvars, linked_to_service, linked_to_container,
+                    container_ports, container_envvars, linked_to_service,
                     'OFF', 'OFF', 'OFF', 'poweruser', True)
 
         mock_exit.assert_called_with(EXCEPTION_EXIT_CODE)
